==> frezka_admin_panel_updated_files_v3.0.0.zip: lang/en/booking.php <==
<?php

return [
    'title' => 'Bookings',
    'singular_title' => 'Booking',
    'lbl_phone' => 'Phone:',
    'lbl_e-mail' => 'E-mail:',
    'lbl_with' => 'With',
    'lbl_at' => 'At:',
    'lbl_note' => 'Note',
    'lbl_sub_tot' => 'Sub Total:',
    'lbl_got_to_payment' => 'Go To Payment',
    'lbl_complete_now' => 'Complete Now',
    'lbl_payment' => 'Payment',
    'lbl_pay_now' => 'Pay Now',
    'lbl_is_paid' => 'Paid',
    'lbl_add_service' => 'Add Service',
    'lbl_readeem_package' => 'Add Package',
    'lbl_date' => 'Date',
    'lbl_customer_name' => 'Customer Name',
    'lbl_amount' => 'Amount',
    'lbl_duration' => 'Duration',
    'lbl_staff_name' => 'Staff Name',
    'lbl_services' => 'Services',
    'lbl_update_at' => 'Updated At',
    'lbl_status' => 'Status',
    'booking_update' => 'Booking updated',
    'booking_status_list' => 'Booking Status List',
    'search_booking' => 'Search results for bookings.',
    'booking_detail' => 'Booking Detail',
    'booking_list' => 'Booking List',
    'status_update' => 'Status has been updated!',
    'booking_delete' => 'Deleted Successfully',
    'booking_not_found' => 'Booking Not Found',
    'payment_done' => 'Payment Successfully',
    'booking_branch' => 'BRANCH_LIST',
    'booking_timeslot' => 'SLOT_TIME_LIST',
    'booking_category' => 'CATEGORY_LIST',
    'booking_sevice' => 'SERVICES_LIST',
    'booking_employee' => 'EMPLOYEE_LIST',
    'booking_create' => 'CREATED_BOOKING',
    'booking_action_invalid' => 'Action Invalid',
    'booking_service_update' => 'Booking Service Updated Successfully',
    'payment_successfull' => 'Payment Successfully Completed',
    'create_form' => ':form has been created successfully',
    'lbl_action' => 'Action',
    'lbl_new_appointment' => 'New Appointment',
    'lbl_appointment' => 'Appointment',
    'lbl_advanced_filter' => 'Advanced Filter',
    'lbl_booking_date' => 'Booking Date',
    'lbl_customer_name' => 'Customer Name',
    'lbl_staff_name' => 'Staff Name',
    'lbl_services' => 'Services',
    'lbl_payment_status' => 'Payment Status',
    'download_invoice' => 'Download Invoice',
    'name' => 'name',
    'phone' => 'phone',
    'email' => 'Email',
    'payment_method' => 'Payment Method',
    'customer_info' => 'Customer Info',
    'services' => 'Services ',
    'unit_price' => 'Unit Price',
    'qty' => 'QTY',
    'total_price' => 'Total Price',
    'tips' => 'Tips',
    'tax' => 'TAX',
    'grand-total' => 'Grand Total',
    'sub_total' => 'Sub Total',
    'products' => ' Products',
    'invoice_data' => ' Invoice Data',
    'coupondiscount'=>'Coupon Discount',
    'grand_total'=>'Grand Total',
    'tips'=>'Tips',
    'billing_address' => 'Billing Address',
    'grand_total' => 'Grand Total:',
];

==> frezka_admin_panel_updated_files_v3.3.0.zip: lang/en/booking.php <==
<?php

return [
    'title' => 'Bookings',
    'singular_title' => 'Booking',
    'lbl_phone' => 'Phone:',
    'lbl_e-mail' => 'E-mail:',
    'lbl_with' => 'With',
    'lbl_at' => 'At:',
    'lbl_note' => 'Note',
    'lbl_sub_tot' => 'Sub Total:',
    'lbl_got_to_payment' => 'Go To Payment',
    'lbl_complete_now' => 'Complete Now',
    'lbl_payment' => 'Payment',
    'lbl_pay_now' => 'Pay Now',
    'lbl_is_paid' => 'Paid',
    'lbl_add_service' => 'Add Service',
    'lbl_readeem_package' => 'Add Package',
    'lbl_date' => 'Date',
    'lbl_customer_name' => 'Client',
    'lbl_amount' => 'Amount',
    'lbl_duration' => 'Duration',
    'lbl_staff_name' => 'Staff Name',
    'lbl_services' => 'Services',
    'lbl_update_at' => 'Updated At',
    'lbl_status' => 'Status',
    'booking_update' => 'Booking updated',
    'booking_status_list' => 'Booking Status List',
    'search_booking' => 'Search results for bookings.',
    'booking_detail' => 'Booking Detail',
    'booking_list' => 'Booking List',
    'status_update' => 'Status has been updated!',
    'booking_delete' => 'Deleted Successfully',
    'booking_not_found' => 'Booking Not Found',
    'payment_done' => 'Payment Successfully',
    'booking_branch' => 'BRANCH_LIST',
    'booking_timeslot' => 'SLOT_TIME_LIST',
    'booking_category' => 'CATEGORY_LIST',
    'booking_sevice' => 'SERVICES_LIST',
    'booking_employee' => 'EMPLOYEE_LIST',
    'booking_create' => 'CREATED_BOOKING',
    'booking_action_invalid' => 'Action Invalid',
    'booking_service_update' => 'Booking Service Updated Successfully',
    'payment_successfull' => 'Payment Successfully Completed',
    'create_form' => ':form has been created successfully',
    'lbl_action' => 'Action',
    'lbl_new_appointment' => 'New Appointment',
    'lbl_appointment' => 'Appointment',
    'lbl_advanced_filter' => 'Advanced Filter',
    'lbl_booking_date' => 'Booking Date',
    
    'lbl_payment_status' => 'Payment Status',
    'download_invoice' => 'Invoice',
    'name' => 'Name',
    'phone' => 'Phone',
    'email' => 'Email',
    'payment_method' => 'Payment Method',
    'customer_info' => 'Customer Info',
    'services' => 'Services ',
    'unit_price' => 'Unit Price',
    'qty' => 'QTY',
    'total_price' => 'Total Price',
    'tips' => 'Tips',
    'tax' => 'TAX',
    'grand-total' => 'Grand Total',
    'sub_total' => 'Sub Total',
    'products' => ' Products',
    'invoice_data' => ' Invoice Date',
    'coupondiscount'=>'Coupon Discount',
    'grand_total'=>'Grand Total',
    'tips'=>'Tips',
    'billing_address' => 'Billing Address',
    'grand_total' => 'Grand Total:',
    'lbl_packages' => 'Packages',
    'lbl_add_more'=>'Add More',
    'lbl_packages_detail'=>'Packages Detail',
    'lbl_package_available'=>' Packages Available ',
    'lbl_package_active'=>'Your package still active',
    'lbl_view_all'=>'View All',
    'booking_date'=>'Select Booking Date',
    'customer_name'=>'Select Customer Name ',
    'staff_name'=>'Select Staff Name ',
    'select_service'=>'Select Services',
    'branch_name'=>'Branch Name',
    'invoice_time' => 'Invoice Time',
    'payment_type' => 'Payment Type',
    'service_amount' => 'Service Amount',
    'product_amount'=> 'Product Amount',
    'package_amount' => 'Package Amount',
    'tip_amount'=>'Tip Amount',
    'total' => 'Total',
    'final_total'=>'Final Total',
    'booking_detail' => 'Booking Detail',
    'booked_on'=> 'Booked On',
    'booked_by'=> 'Booked By',
    'updated_on'=>'Updated On',
    'updated_by'=>'Updated By',
    'sale'=>'Sale #0',
    'with'=>'With',
    'sold_by'=>'Sold By',
    'client_since'=>'Client since ',
    'sale'=>'Sale',
    'coupon_discount'=>'Coupon Discount',


];
